@@ -114,7 +114,6 @@ class Manifest:
 
         self._hyperthought_root = hyperthought_root.replace("\\", "/")
         self._hyperthought_root_id_path = None
-        self._database_connection = None
         self._database = None
         self._file_info_computed = False
 
@@ -132,13 +131,11 @@ class Manifest:
     def _create_database(self) -> None:
         """Create new database.  Load job information."""
         self._validate_job_data()
-        self._database_connection = database.connect.get_connection(
+        connection = database.connect.get_connection(
             manifest_path=self._manifest_file,
             overwrite=True,
         )
-        self._database = database.manage.DatabaseManager(
-            db_connection=self._database_connection
-        )
+        self._database = database.Database(connection=connection)
         self._database.create_job_data(
             job_name=self._job_name,
             username=self._username,
@@ -181,13 +178,11 @@ class Manifest:
 
     def _set_database(self) -> None:
         """Connect to existing database."""
-        self._database_connection = database.connect.get_connection(
+        connection = database.connect.get_connection(
             manifest_path=self._manifest_file,
             overwrite=False,
         )
-        self._database = database.manage.DatabaseManager(
-            db_connection=self._database_connection
-        )
+        self._database = database.Database(connection=connection)
         job_data = self._database.get_job_data()
 
         if job_data is None:
@@ -205,10 +200,10 @@ class Manifest:
         if not stripped_root:
             return
 
-        cursor = self._database_connection.cursor()
+        cursor = self.database.connection.cursor()
 
         def get_hyperthought_id(name, hyperthought_id_path):
-            # TODO:  Remove SQL from this module.  See IC-????.
+            # TODO:  Remove SQL from this module.  See IC-7272.
             sql = """
             SELECT hyperthought_id
             FROM File
@@ -239,7 +234,7 @@ class Manifest:
 
             if not hyperthought_id:
                 hyperthought_id = utils.generate_id()
-                self._database.create_file(
+                self.database.create_file(
                     name=folder_name,
                     is_folder=True,
                     hyperthought_id=hyperthought_id,
@@ -287,15 +282,19 @@ class Manifest:
         if not self._hyperthought_root.startswith("/"):
             raise ValueError("hyperthought_root must start with '/'")
 
+    @property
+    def database(self):
+        return self._database
+
     @property
     def common_metadata(self) -> List[MetadataItem]:
         return ht.metadata.from_api_format(
-            self._database.get_common_metadata())
+            self.database.get_common_metadata())
 
     @common_metadata.setter
     def common_metadata(self, metadata: List[MetadataItem]) -> None:
         self._validate_metadata(metadata)
-        self._database.create_or_update_common_metadata(metadata=metadata)
+        self.database.create_or_update_common_metadata(metadata=metadata)
 
     @property
     def ignore_path(self) -> Optional[str]:
@@ -384,8 +383,8 @@ class Manifest:
             # Maintain the invariant that break_index is the index of the
             # first folder that *doesn't* exist.
             break_index += 1
-            ancestor_id = self._database.get_file_id(path=ancestor_path)
-            ancestor = self._database.get_file(file_id=ancestor_id)
+            ancestor_id = self.database.get_file_id(path=ancestor_path)
+            ancestor = self.database.get_file(file_id=ancestor_id)
             ht_id_path = (
                 f"{ancestor['hyperthought_id_path']}"
                 f"{ancestor['hyperthought_id']},"
@@ -435,7 +434,7 @@ class Manifest:
         )
 
         # Create all records.
-        self._database.bulk_load_files(file_data=file_data)
+        self.database.bulk_load_files(file_data=file_data)
 
     def remove_path(self, path: str) -> None:
         """
@@ -455,7 +454,7 @@ class Manifest:
             )
 
         for id_ in ids_to_remove:
-            self._database.delete_file(file_id=id_)
+            self.database.delete_file(file_id=id_)
 
     def _validate_path(self, path: str) -> None:
         """
@@ -481,13 +480,13 @@ class Manifest:
     def has_path(self, path: str) -> bool:
         """Determine whether a path has already been added."""
         path = utils.clean_path(path)
-        file_id = self._database.get_file_id(path=path)
+        file_id = self.database.get_file_id(path=path)
         return file_id is not None
 
     def get_path_id(self, path: str) -> int:
         """Get internal id associated with a path."""
         path = utils.clean_path(path)
-        path_id = self._database.get_file_id(path=path)
+        path_id = self.database.get_file_id(path=path)
 
         if path_id is None:
             raise PathNotFoundException(
@@ -512,7 +511,7 @@ class Manifest:
         -------
         A list of file records for paths under the given folder.
         """
-        return self._database.get_progeny(folder_path=folder_path)
+        return self.database.get_progeny(folder_path=folder_path)
 
     def _validate_parser(self, parser_class_name: str) -> None:
         if parser_class_name not in ht.parsers.PARSERS:
@@ -541,7 +540,7 @@ class Manifest:
             raise ValueError("apply_to_file_ids must not be empty")
 
         self._validate_parser(parser_class_name)
-        metadata_id = self._database.create_metadata()
+        metadata_id = self.database.create_metadata()
         metadata_application_data = [
             {
                 "metadata_id": metadata_id,
@@ -549,10 +548,10 @@ class Manifest:
             }
             for file_id in apply_to_file_ids
         ]
-        self._database.bulk_load_metadata_application(
+        self.database.bulk_load_metadata_application(
             metadata_application_data=metadata_application_data
         )
-        self._database.create_parser(
+        self.database.create_parser(
             file_id=file_id,
             parser_class=parser_class_name,
             metadata_id=metadata_id,
@@ -578,7 +577,7 @@ class Manifest:
             {"metadata_id": metadata_id, "file_id": file_id}
             for file_id in apply_to_file_ids
         ]
-        self._database.bulk_load_metadata_application(
+        self.database.bulk_load_metadata_application(
             metadata_application_data=metadata_application_data
         )
 
@@ -603,7 +602,7 @@ class Manifest:
         if n_processes is None:
             n_processes = multiprocessing.cpu_count() * 2
 
-        files = self._database.get_all_files()
+        files = self.database.get_all_files()
         pool = multiprocessing.Pool(processes=n_processes)
         all_updates = pool.map(_compute_size_hash_and_end_bytes, files)
         pool.close()
@@ -611,16 +610,16 @@ class Manifest:
 
         for updates in all_updates:
             id_ = updates.pop("id")
-            self._database.update_file(id_=id_, updates=updates)
+            self.database.update_file(id_=id_, updates=updates)
 
     def _compute_file_info_without_pool(self) -> None:
         """Compute file hashes and end bytes in the current process."""
-        files = self._database.get_all_files()
+        files = self.database.get_all_files()
 
         for file_ in files:
             updates = _compute_size_hash_and_end_bytes(file_=file_)
             id_ = updates.pop("id")
-            self._database.update_file(id_=id_, updates=updates)
+            self.database.update_file(id_=id_, updates=updates)
 
     def compute_file_info(
         self,
@@ -635,6 +634,10 @@ class Manifest:
 
         self._file_info_computed = True
 
+    def get_total_size(self) -> int:
+        """Get the sum of file sizes for all files in the manifest."""
+        return self.database.get_total_size()
+
     def close(self, compute_file_info: bool = True) -> None:
         """
         Close the manifest (database).
@@ -648,8 +651,7 @@ class Manifest:
         if compute_file_info and not self.file_info_computed:
             self.compute_file_info()
 
-        self._database_connection.close()
-
+        self.database.connection.close()
 
 def from_json(manifest_data: Dict, manifest_database_file: str) -> Manifest:
     """
